from poetry_project.util import get_poetry_attribute, load_toml_from_package


def get_version(package=__package__):
    try:
        return get_poetry_attribute('version', package)
    except ValueError:
        import importlib_metadata
        return importlib_metadata.version(package)


def get_name(package=__package__):
    return get_poetry_attribute('name', package)


def get_authors(package=__package__):
    return get_poetry_attribute('authors', package)


def get_dependencies(package=__package__):
    return get_poetry_attribute('dependencies', package)


def get_toml(package=__package__, toml_file_name='pyproject.toml'):
    return load_toml_from_package(package, toml_file_name)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['poetry_project']

package_data = \
{'': ['*']}

install_requires = \
['importlib-metadata>=1.5.0,<2.0.0',
 'importlib-resources>=1.4.0,<2.0.0',
 'tomlkit>=0.5.11,<0.6.0']

setup_kwargs = {
    'name': 'poetry-project',
    'version': '0.3.0',
    'description': 'Read poetry project information such as name, version and description.',
    'long_description': None,
    'author': 'Julian Stier',
    'author_email': 'mail@julian-stier.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.5,<4.0',
}


setup(**setup_kwargs)



from importlib_resources import files
import tomlkit


def load_toml_from_package(package, project_file_name='pyproject.toml'):
    if package is None:
        raise ValueError('Expected package to load a <{file}>-file from, but got <{package}>'.format(file=project_file_name, package=str(package)))

    package_path = files(package)

    while package_path.parent != package_path:
        possible_project_file_path = package_path.joinpath(project_file_name)
        if possible_project_file_path.exists():
            return tomlkit.parse(possible_project_file_path.read_text())
        package_path = package_path.parent

    raise ValueError('Could not find <{file}>-file in package <{package}>'.format(file=project_file_name, package=str(package)))


def get_poetry_attribute(attribute_name, package, pyproject_toml=None, project_file_name='pyproject.toml'):
    if pyproject_toml is None:
        pyproject_toml = load_toml_from_package(package, project_file_name)

    if pyproject_toml is None:
        return None

    if 'tool' not in pyproject_toml or 'poetry' not in pyproject_toml['tool']:
        return None

    attribute_path = attribute_name.split('.')
    unwrapped = pyproject_toml['tool']['poetry']
    for attribute in attribute_path:
        if attribute not in unwrapped:
            return None
        unwrapped = unwrapped[attribute]
    return unwrapped
